summaryrefslogtreecommitdiffstats
path: root/parts/filecreate/addglobaldlg.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'parts/filecreate/addglobaldlg.cpp')
-rw-r--r--parts/filecreate/addglobaldlg.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/parts/filecreate/addglobaldlg.cpp b/parts/filecreate/addglobaldlg.cpp
index ca31669f..93914a2f 100644
--- a/parts/filecreate/addglobaldlg.cpp
+++ b/parts/filecreate/addglobaldlg.cpp
@@ -21,14 +21,14 @@
#include <klocale.h>
/*
* Constructs a AddGlobalDlg as a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'.
*
* The dialog will by default be modeless, unless you set 'modal' to
* TRUE to construct a modal dialog.
*/
-AddGlobalDlg::AddGlobalDlg( TQWidget* tqparent, const char* name, bool modal, WFlags fl )
- : TQDialog( tqparent, name, modal, fl )
+AddGlobalDlg::AddGlobalDlg( TQWidget* parent, const char* name, bool modal, WFlags fl )
+ : TQDialog( parent, name, modal, fl )
{
if ( !name )
@@ -21,14 +21,14 @@
#include <klocale.h>
/*
- * Constructs a AddGlobalDlg as a child of 'tqparent', with the
+ * Constructs a AddGlobalDlg as a child of 'parent', with the
* name 'name' and widget flags set to 'f'.
*